@@ -58,18 +58,69 @@
 #	include <sys/stat.h>
 #endif
 
+#ifndef WIN32
+#ifndef __APPLE__
+#	include "unistd.h"
+#endif
+#endif
+
 namespace GAGCore
 {
 	FileManager::FileManager(const char *gameName)
 	{
 		#ifndef WIN32
-		std::string gameLocal(getenv("HOME"));
-		gameLocal += "/.";
-		gameLocal += gameName;
-		mkdir(gameLocal.c_str(), S_IRWXU);
-		addDir(gameLocal.c_str());
+		const char *homeDir = getenv("HOME");
+		if (homeDir)
+		{
+			std::string gameLocal(homeDir);
+			gameLocal += "/.";
+			gameLocal += gameName;
+			mkdir(gameLocal.c_str(), S_IRWXU);
+			addDir(gameLocal.c_str());
+		}
+		else
+			std::cerr << "FileManager::FileManager : warning, can't get home directory by using getenv(\"HOME\")" << std::endl;
 		#endif
 		addDir(".");
+
+		#ifndef WIN32 	
+		#ifndef __APPLE__
+		/* Find own path
+		 * TODO: Make nicer */
+		
+		char link[100];
+		char proc[]="/proc/self/exe";
+		char * pch;
+
+		int linksize = readlink(proc, link, sizeof(link));
+		if (linksize < 0)
+		{
+			perror("readlink() error");
+		}
+		else
+		{
+			assert ((int)sizeof(link) > linksize); 
+			link[linksize] = '\0';
+
+			pch = strrchr(link,'/');	
+			if ( (pch-link) > 0) 
+				link[pch-link] = '\0';
+			else
+				link[1] = '\0';
+
+			pch = strrchr(link,'/');	
+			if ( (pch-link) > 0) 
+				link[pch-link] = '\0';
+
+			if ((linksize + 13) <= (int)sizeof(link))
+			{
+				strcat(link, "/share/glob2");
+				addDir(link);
+			}
+		}
+		#endif
+		#endif
+
 		addDir(PACKAGE_DATA_DIR);
 		addDir(PACKAGE_SOURCE_DIR);
 		fileListIndex = -1;
