@@ -93,6 +93,7 @@ namespace GAGCore
 	// Cache for GL state, call gl only if necessary. GL optimisations
 	static struct GLState
 	{
+		static const bool verbose = false;
 		int _doBlend;
 		int _doTexture;
 		int _doScissor;
@@ -116,10 +117,11 @@ namespace GAGCore
 			const char *glExtensions = (const char *)glGetString(GL_EXTENSIONS);
 			isTextureRectangle = (strstr(glExtensions, "GL_NV_texture_rectangle") != NULL);
 			isTextureRectangle = isTextureRectangle || (strstr(glExtensions, "GL_EXT_texture_rectangle") != NULL);
-			if (isTextureRectangle)
-				std::cout << "Toolkit : GL_NV_texture_rectangle or GL_EXT_texture_rectangle extension present, optimal texture size will be used" << std::endl;
-			else
-				std::cout << "Toolkit : GL_NV_texture_rectangle or GL_EXT_texture_rectangle extension not present, power of two texture will be used" << std::endl;
+			if (verbose)
+				if (isTextureRectangle)
+					std::cout << "Toolkit : GL_NV_texture_rectangle or GL_EXT_texture_rectangle extension present, optimal texture size will be used" << std::endl;
+				else
+					std::cout << "Toolkit : GL_NV_texture_rectangle or GL_EXT_texture_rectangle extension not present, power of two texture will be used" << std::endl;
 		}
 		
 		void doBlend(int on)
@@ -1011,20 +1013,61 @@ namespace GAGCore
 	{
 		if (alpha == Color::ALPHA_OPAQUE)
 		{
-			// well, we *hope* SDL is faster than a handmade code
-			SDL_Rect sr, dr;
-			sr.x = static_cast<Sint16>(sx);
-			sr.y = static_cast<Sint16>(sy);
-			sr.w = static_cast<Uint16>(sw);
-			sr.h = static_cast<Uint16>(sh);
-			dr.x = static_cast<Sint16>(x);
-			dr.y = static_cast<Sint16>(y);
-			dr.w = static_cast<Uint16>(sw);
-			dr.h = static_cast<Uint16>(sh);
-			SDL_BlitSurface(surface->sdlsurface, &sr, sdlsurface, &dr);
+			if ((surface == _gc) && (_gc->getOptionFlags() & GraphicContext::USEGPU))
+			{
+				if ((x == 0) && (y == 0) && (sdlsurface->w == sw) && (sdlsurface->h == sh))
+				{
+					std::valarray<unsigned> tempPixels(sw*sh);
+					#if SDL_BYTEORDER == SDL_BIG_ENDIAN
+					glReadPixels(sx, sy, sdlsurface->w, sdlsurface->h, GL_RGBA, GL_UNSIGNED_BYTE, &tempPixels[0]);
+					#else
+					glReadPixels(sx, sy, sdlsurface->w, sdlsurface->h, GL_BGRA, GL_UNSIGNED_BYTE, &tempPixels[0]);
+					#endif
+					for (int y = 0; y<sh; y++)
+					{
+						unsigned *srcPtr = (unsigned *)&tempPixels[y*sw];
+						unsigned *destPtr = &(((unsigned *)sdlsurface->pixels)[(sh-y-1)*sw]);
+						for (int x = 0; x<sw; x++)
+						#if SDL_BYTEORDER == SDL_BIG_ENDIAN
+						{
+							*destPtr++ = (*srcPtr >> 8) | (*srcPtr << 24);
+							srcPtr++;
+						}
+						#else
+							*destPtr++ = *srcPtr++;
+						#endif
+					}
+					
+				}
+				else
+				{
+					std::cerr << "Partial blitting to from framebuffer in GL is forbidden" << std::endl;
+					assert(false);
+				}
+			}
+			else
+			{
+				// well, we *hope* SDL is faster than a handmade code
+				SDL_Rect sr, dr;
+				sr.x = static_cast<Sint16>(sx);
+				sr.y = static_cast<Sint16>(sy);
+				sr.w = static_cast<Uint16>(sw);
+				sr.h = static_cast<Uint16>(sh);
+				dr.x = static_cast<Sint16>(x);
+				dr.y = static_cast<Sint16>(y);
+				dr.w = static_cast<Uint16>(sw);
+				dr.h = static_cast<Uint16>(sh);
+				SDL_BlitSurface(surface->sdlsurface, &sr, sdlsurface, &dr);
+			}
 		}
 		else
 		{
+			if ((surface == _gc) && (_gc->getOptionFlags() & GraphicContext::USEGPU))
+			{
+				std::cerr << "Blitting with alphablending from framebuffer in GL is forbidden" << std::endl;
+				assert(false);
+			}
+			
 			// check we assume the source rect is within the source surface
 			assert((sx >= 0) && (sx < surface->getW()));
 			assert((sy >= 0) && (sy < surface->getH()));
@@ -1605,7 +1648,8 @@ namespace GAGCore
 		}
 		else
 		{
-			fprintf(stderr, "Toolkit : Initialized : Graphic Context created\n");
+			if (verbose)
+				fprintf(stderr, "Toolkit : Initialized : Graphic Context created\n");
 		}
 	
 		SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
@@ -1621,8 +1665,9 @@ namespace GAGCore
 		TTF_Quit();
 		SDL_Quit();
 		sdlsurface = NULL;
-		
-		fprintf(stderr, "Toolkit : Graphic Context destroyed\n");
+
+		if (verbose)
+			fprintf(stderr, "Toolkit : Graphic Context destroyed\n");
 	}
 	
 	bool GraphicContext::setRes(int w, int h, Uint32 flags)
@@ -1630,12 +1675,14 @@ namespace GAGCore
 		// check dimension
 		if (minW && (w < minW))
 		{
-			fprintf(stderr, "Toolkit : Screen width %d is too small, set to min %d\n", w, minW);
+			if (verbose)
+				fprintf(stderr, "Toolkit : Screen width %d is too small, set to min %d\n", w, minW);
 			w = minW;
 		}
 		if (minH && (h < minH))
 		{
-			fprintf(stderr, "Toolkit : Screen height %d is too small, set to min %d\n", h, minH);
+			if (verbose)
+				fprintf(stderr, "Toolkit : Screen height %d is too small, set to min %d\n", h, minH);
 			h = minH;
 		}
 		
@@ -1717,10 +1764,12 @@ namespace GAGCore
 			else
 				SDL_ShowCursor(SDL_ENABLE);
 			
-			if (flags & FULLSCREEN)
-				fprintf(stderr, "Toolkit : Screen set to %dx%d at 32 bpp in fullscreen\n", w, h);
-			else
-				fprintf(stderr, "Toolkit : Screen set to %dx%d at 32 bpp in window\n", w, h);
+			if (verbose)
+				fprintf(stderr,
+					(flags & FULLSCREEN)
+					?"Toolkit : Screen set to %dx%d at 32 bpp in fullscreen\n"
+					:"Toolkit : Screen set to %dx%d at 32 bpp in window\n",
+					w, h);
 			
 			#ifdef HAVE_OPENGL
 			if (optionFlags & USEGPU)
