@@ -29,6 +29,8 @@
 #include "AINumbi.h"
 #include "AICastor.h"
 #include "AIToubib.h"
+#include "AIWarrush.h"
+#include "AINicowar.h"
 
 /*AI::AI(Player *player)
 {
@@ -52,9 +54,15 @@ AI::AI(ImplementitionID implementitionID, Player *player)
 		case CASTOR:
 			aiImplementation=new AICastor(player);
 		break;
+		case NICOWAR:
+			aiImplementation=new AINicowar(player);
+		break;
 		case TOUBIB:
 			aiImplementation=new AIToubib(player);
 		break;
+		case WARRUSH:
+			aiImplementation=new AIWarrush(player);
+		break;
 		default:
 			assert(false);
 		break;
@@ -124,10 +132,17 @@ bool AI::load(GAGCore::InputStream *stream, Sint32 versionMinor)
 		case CASTOR:
 			aiImplementation=new AICastor(stream, player, versionMinor);
 		break;
+		case NICOWAR:
+			aiImplementation=new AINicowar(stream, player, versionMinor);
+		break;
 		case TOUBIB:
 			aiImplementation=new AIToubib(stream, player, versionMinor);
 		break;
+		case WARRUSH:
+			aiImplementation=new AIWarrush(stream, player, versionMinor);
+		break;
 		default:
+			fprintf(stderr, "AI id %d does not exist, you probably try to load a map from a more recent version of glob2.\n", implementitionID);
 			assert(false);
 		break;
 	}
