@@ -89,7 +89,7 @@ Building::Building(int x, int y, Uint16 gid, Sint32 typeNum, Team *team, Buildin
 	clearingRessources[STONE]=false;
 	memcpy(clearingRessourcesLocal, clearingRessources, sizeof(bool)*BASIC_COUNT);
 	minLevelToFlag=0;
-	minLevelToFlagLocal=0;
+	minLevelToFlagLocal=minLevelToFlag;
 	
 	// building specific :
 	for(int i=0; i<MAX_NB_RESSOURCES; i++)
@@ -433,7 +433,7 @@ void Building::saveCrossRef(GAGCore::OutputStream *stream)
 	// units
 	stream->writeSint32(maxUnitInside, "maxUnitInside");
 	stream->writeUint32(unitsWorking.size(), "nbWorking");
-	fprintf(logFile, " nbWorking=%d\n", unitsWorking.size());
+	fprintf(logFile, " nbWorking=%zd\n", unitsWorking.size());
 	i = 0;
 	for (std::list<Unit *>::iterator it=unitsWorking.begin(); it!=unitsWorking.end(); ++it)
 	{
@@ -445,7 +445,7 @@ void Building::saveCrossRef(GAGCore::OutputStream *stream)
 	}
 
 	stream->writeUint32(unitsWorkingSubscribe.size(), "nbWorkingSubscribe");
-	fprintf(logFile, " nbWorkingSubscribe=%d\n", unitsWorkingSubscribe.size());
+	fprintf(logFile, " nbWorkingSubscribe=%zd\n", unitsWorkingSubscribe.size());
 	i = 0;
 	for (std::list<Unit *>::iterator it=unitsWorkingSubscribe.begin(); it!=unitsWorkingSubscribe.end(); ++it)
 	{
@@ -461,7 +461,7 @@ void Building::saveCrossRef(GAGCore::OutputStream *stream)
 	stream->writeSint32(maxUnitWorkingPreferred, "maxUnitWorkingPreferred");
 	
 	stream->writeUint32(unitsInside.size(), "nbInside");
-	fprintf(logFile, " nbInside=%d\n", unitsInside.size());
+	fprintf(logFile, " nbInside=%zd\n", unitsInside.size());
 	i = 0;
 	for (std::list<Unit *>::iterator  it=unitsInside.begin(); it!=unitsInside.end(); ++it)
 	{
@@ -473,7 +473,7 @@ void Building::saveCrossRef(GAGCore::OutputStream *stream)
 	}
 
 	stream->writeUint32(unitsInsideSubscribe.size(), "nbInsideSubscribe");
-	fprintf(logFile, " nbInsideSubscribe=%d\n", unitsInsideSubscribe.size());
+	fprintf(logFile, " nbInsideSubscribe=%zd\n", unitsInsideSubscribe.size());
 	i = 0;
 	for (std::list<Unit *>::iterator  it=unitsInsideSubscribe.begin(); it!=unitsInsideSubscribe.end(); ++it)
 	{
@@ -1190,7 +1190,8 @@ bool Building::tryToBuildingSiteRoom(void)
 				{
 					if (res>resMax)
 						res=resMax;
-					printf("using %d ressources[%d] for fast constr (hp+=%d)\n", res, i, res*type->hpInc);
+					if (verbose)
+						printf("using %d ressources[%d] for fast constr (hp+=%d)\n", res, i, res*type->hpInc);
 					hp+=res*type->hpInc;
 				}
 			}
@@ -1358,16 +1359,16 @@ void Building::subscribeToBringRessourcesStep()
 						int y=unit->posY;
 						bool canSwim=unit->performance[SWIM];
 						int timeLeft=(unit->hungry-unit->trigHungry)/unit->race->hungryness;
-						for (int r=0; r<MAX_RESSOURCES; r++)
+						int distUnitBuilding;
+						if (map->buildingAvailable(this, canSwim, x, y, &distUnitBuilding) && distUnitBuilding<timeLeft)
 						{
-							int need=needs[r];
-							if (need>0)
+							for (int r=0; r<MAX_RESSOURCES; r++)
 							{
-								int distUnitRessource;
-								if (map->ressourceAvailable(teamNumber, r, canSwim, x, y, &distUnitRessource) && (distUnitRessource<timeLeft))
+								int need=needs[r];
+								if (need>0)
 								{
-									int distUnitBuilding;
-									if (map->buildingAvailable(this, canSwim, x, y, &distUnitBuilding) && distUnitBuilding<timeLeft)
+									int distUnitRessource;
+									if (map->ressourceAvailable(teamNumber, r, canSwim, x, y, &distUnitRessource) && (distUnitRessource<timeLeft))
 									{
 										int value=((distUnitRessource+distUnitBuilding)<<8)/need;
 										if (value<minValue)
@@ -1482,16 +1483,16 @@ void Building::subscribeToBringRessourcesStep()
 						int y=unit->posY;
 						bool canSwim=unit->performance[SWIM];
 						int timeLeft=(unit->hungry-unit->trigHungry)/unit->race->hungryness;
-						for (int r=0; r<MAX_RESSOURCES; r++)
+						int distUnitBuilding;
+						if (map->buildingAvailable(this, canSwim, x, y, &distUnitBuilding) && distUnitBuilding<timeLeft)
 						{
-							int need=needs[r];
-							if (need>0)
+							for (int r=0; r<MAX_RESSOURCES; r++)
 							{
-								int distUnitRessource;
-								if (map->ressourceAvailable(teamNumber, r, canSwim, x, y, &distUnitRessource) && (distUnitRessource<timeLeft))
+								int need=needs[r];
+								if (need>0)
 								{
-									int distUnitBuilding;
-									if (map->buildingAvailable(this, canSwim, x, y, &distUnitBuilding) && distUnitBuilding<timeLeft)
+									int distUnitRessource;
+									if (map->ressourceAvailable(teamNumber, r, canSwim, x, y, &distUnitRessource) && (distUnitRessource<timeLeft))
 									{
 										int value=((distUnitRessource+distUnitBuilding)<<8)/need;
 										if (value<minValue)
@@ -1752,7 +1753,7 @@ void Building::swarmStep(void)
 					for (int i=0; i<NB_UNIT_TYPE; i++)
 						percentUsed[i]=0;
 			}
-			else
+			else if (verbose)
 				printf("WARNING, no more UNIT ID free for team %d\n", owner->teamNumber);
 		}
 	}
@@ -2014,7 +2015,7 @@ void Building::kill(void)
 		return;
 	
 	
-	fprintf(logFile, " still %d unitsInside\n", unitsInside.size());
+	fprintf(logFile, " still %zd unitsInside\n", unitsInside.size());
 	for (std::list<Unit *>::iterator it=unitsInside.begin(); it!=unitsInside.end(); ++it)
 	{
 		Unit *u=*it;
@@ -2035,7 +2036,7 @@ void Building::kill(void)
 	}
 	unitsInside.clear();
 
-	fprintf(logFile, " still %d unitsWorking\n", unitsInside.size());
+	fprintf(logFile, " still %zd unitsWorking\n", unitsInside.size());
 	for (std::list<Unit *>::iterator it=unitsWorking.begin(); it!=unitsWorking.end(); ++it)
 	{
 		assert(*it);
