@@ -246,6 +246,7 @@ void Game::executeOrder(Order *order, int localPlayer)
 			if ((b) && (b->buildingState==Building::ALIVE))
 			{
 				fprintf(logFile, "ORDER_MODIFY_BUILDING");
+				assert(omb->numberRequested <= 20 && omb->numberRequested >= 0);
 				b->maxUnitWorking=omb->numberRequested;
 				b->maxUnitWorkingPreferred=b->maxUnitWorking;
 				if (order->sender!=localPlayer)
@@ -352,21 +353,31 @@ void Game::executeOrder(Order *order, int localPlayer)
 			}
 		}
 		break;
-		case ORDER_MODIFY_WAR_FLAG:
+		case ORDER_MODIFY_MIN_LEVEL_TO_FLAG:
 		{
 			if (!isPlayerAlive)
 				break;
-			OrderModifyWarFlag *omwf=(OrderModifyWarFlag *)order;
+			OrderModifyMinLevelToFlag *omwf=(OrderModifyMinLevelToFlag *)order;
 			int team=Building::GIDtoTeam(omwf->gid);
 			int id=Building::GIDtoID(omwf->gid);
 			Building *b=teams[team]->myBuildings[id];
 			if (b
 				&& b->buildingState==Building::ALIVE
 				&& b->type->defaultUnitStayRange
-				&& b->type->zonable[WARRIOR])
+				&& (b->type->zonable[WARRIOR] || b->type->zonable[EXPLORER]))
 			{
-				fprintf(logFile, "ORDER_MODIFY_WAR_FLAG");
-				b->minLevelToFlag=omwf->minLevelToFlag;
+				fprintf(logFile, "ORDER_MODIFY_MIN_LEVEL_TO_FLAG");
+				b->minLevelToFlag = omwf->minLevelToFlag;
+				// if it was another player, update local
+				if (order->sender != localPlayer)
+					b->minLevelToFlagLocal = b->minLevelToFlag;
+					
+				// flush all the actual units
+				int maxUnitWorkingSaved = b->maxUnitWorking;
+				b->maxUnitWorking = 0;
+				b->update();
+				b->maxUnitWorking = maxUnitWorkingSaved;
+				b->update();
 			}
 		}
 		break;
@@ -721,7 +732,8 @@ void Game::setAIAlliance(void)
 {
 	if (isHumanAllAllied())
 	{
-		printf("Game : AIs are now allied vs human\n");
+		if (verbose)
+			printf("Game : AIs are now allied vs human\n");
 		
 		// all human are allied, ally AI
 		Uint32 aiMask = 0;
@@ -731,7 +743,8 @@ void Game::setAIAlliance(void)
 			if (teams[i]->type == BaseTeam::T_AI)
 				aiMask |= (1<<i);
 		
-		printf("AI mask : %x\n", aiMask);
+		if (verbose)
+			printf("AI mask : %x\n", aiMask);
 				
 		// ally them together
 		for (int i=0; i<session.numberOfTeam; i++)
@@ -743,7 +756,8 @@ void Game::setAIAlliance(void)
 	}
 	else
 	{
-		printf("Game : AIs are now in ffa mode\n");
+		if (verbose)
+			printf("Game : AIs are now in ffa mode\n");
 		
 		// free for all on AI side
 		for (int i=0; i<session.numberOfTeam; i++)
@@ -785,7 +799,8 @@ bool Game::load(GAGCore::InputStream *stream)
 
 	// We load the file's header:
 	SessionInfo tempSessionInfo;
-	printf("Loading map header\n");
+	if (verbose)
+		printf("Loading map header\n");
 	if (!tempSessionInfo.load(stream))
 	{
 		fprintf(logFile, "Game::load::tempSessionInfo.load\n");
@@ -1109,6 +1124,7 @@ void Game::wonSyncStep(void)
 {
 	totalPrestige=0;
 	isGameEnded=false;
+	int greatestPrestige=0;
 	
 	for (int i=0; i<session.numberOfTeam; i++)
 	{
@@ -1121,11 +1137,16 @@ void Game::wonSyncStep(void)
 		teams[i]->hasWon |= !isOtherAlive;
 		isGameEnded |= teams[i]->hasWon;
 		totalPrestige += teams[i]->prestige;
+		if (greatestPrestige < teams[i]->prestige) greatestPrestige = teams[i]->prestige;
 	}
+
 	if (totalPrestige >= prestigeToReach)
 	{
 		totalPrestigeReached=true;
 		isGameEnded=true;
+
+		for (int i=0; i<session.numberOfTeam; i++)
+			teams[i]->hasWon = teams[i]->prestige == greatestPrestige;
 	}
 }
 
