@@ -69,7 +69,7 @@ bool IRC::connect(const char *serverName, int serverPort, const char *nick)
 	}
 
 	SDLNet_TCP_AddSocket(socketSet, socket);
-        
+	
 	// Here we change the nick on yog for the IRC
 	// changing from nick = "nick" to YOGnick = "YOGnick"
 	memcpy(this->nick, "[YOG]", 5);
@@ -150,7 +150,17 @@ void IRC::interpreteIRCMessage(const char *message)
 	}
 
 	// this is a debug printf to reverse engineer IRC protocol
-	//printf("IRC command is : [%s] Source is [%s]\n", cmd, source);
+	if (verbose)
+		printf("IRC command is : [%s] Source is [%s] Prefix is [%s]\n", cmd, source, prefix);
+	if (strcasecmp(cmd, "PING")==0)
+	{
+		char *argument=strtok(NULL, " \0");
+		if (verbose)
+			printf("IRC got PING, responding PONG with argument [%s]\n", argument);
+		std::string answer("PONG ");
+		answer += argument;
+		sendString(answer.c_str());
+	}
 	if (strcasecmp(cmd, "PRIVMSG")==0)
 	{
 		char *diffusion=strtok(NULL, " :");
@@ -301,7 +311,6 @@ void IRC::interpreteIRCMessage(const char *message)
 			}
 		}
 	}
-
 }
 
 void IRC::step(void)
@@ -322,7 +331,8 @@ void IRC::step(void)
 			bool res=getString(data);
 			if (res)
 			{
-				printf("YOG (IRC) has received [%s]\n", data);
+				if (verbose)
+					printf("YOG (IRC) has received [%s]\n", data);
 				interpreteIRCMessage(data);
 			}
 			else
@@ -430,7 +440,8 @@ void IRC::sendCommand(const char *message)
 		char *cmd=strtok(tempMessage, " \t");
 		char *arg1=strtok(NULL, " \t");
 		char *arg2=strtok(NULL, "\0");
-		printf ("c = [%s] a1 = [%s] a2 = [%s]\n", cmd, arg1, arg2);
+		if (verbose)
+			printf ("c = [%s] a1 = [%s] a2 = [%s]\n", cmd, arg1, arg2);
 		if ((strcasecmp(cmd, "/msg")==0) && arg1 && arg2)
 		{
 			snprintf(command, IRC_MESSAGE_SIZE, "PRIVMSG %s :%s", arg1, arg2);
@@ -457,7 +468,8 @@ void IRC::sendCommand(const char *message)
 	else
 	{
 		snprintf(command, IRC_MESSAGE_SIZE, "PRIVMSG %s :%s", chatChan, message);
-		printf("YOG::sendString(%s).\n", command);
+		if (verbose)
+			printf("YOG::sendString(%s).\n", command);
 		sendString(command);
 	}
 }
@@ -557,12 +569,13 @@ bool IRC::getString(char data[IRC_MESSAGE_SIZE])
 	}
 }
 
-bool IRC::sendString(char *data)
+bool IRC::sendString(const char *data)
 {
 	if (socket)
 	{
 		char ircMsg[IRC_MESSAGE_SIZE];
 		snprintf(ircMsg, IRC_MESSAGE_SIZE-1, "%s", data);
+		ircMsg[IRC_MESSAGE_SIZE-1] = 0;
 		int len=strlen(ircMsg);
 		ircMsg[len]='\r';
 		ircMsg[len+1]='\n';
