@@ -66,6 +66,7 @@ struct Case
 */
 class Map
 {
+	static const bool verbose = false;
 public:
 	//! Type of terrain (used for undermap)
 
@@ -560,8 +561,9 @@ protected:
 	//Used for scheduling computation time.
 	bool gradientUpdated[32][MAX_NB_RESSOURCES][2];
 	Uint8 *undermap;
+	Uint8 **listedAddr;
 	size_t size;
-	
+
 	Sector *sectors;
 	Sint32 wSector, hSector;
 	int sizeSector;
@@ -570,9 +572,10 @@ protected:
 
 public:
 	Uint32 checkSum(bool heavy);
-	Sint32 warpDistSquare(int px, int py, int qx, int qy); //The distance between (px, py) and (qx, qy), warp-safe, but not rooted.
-	Sint32 warpDistMax(int px, int py, int qx, int qy); //The max distance on x or y axis, between (px, py) and (qx, qy), warp-safe.
-	bool isInLocalGradient(int ux, int uy, int bx, int by); //Return true if the unit @(ux, uy) is close enough of building @(bx, by).
+	Sint32 warpDistSquare(int px, int py, int qx, int qy); //!< The distance between (px, py) and (qx, qy), warp-safe, but not rooted.
+	Sint32 warpDistMax(int px, int py, int qx, int qy); //!< The max distance on x or y axis, between (px, py) and (qx, qy), warp-safe.
+	bool isInLocalGradient(int ux, int uy, int bx, int by); //!< Return true if the unit @(ux, uy) is close enough of building @(bx, by).
+	void dumpGradient(Uint8 *gradient, const char *filename = "gradient.dump.pgm");
 
 public:
 	void makeHomogenMap(TerrainType terrainType);
