@@ -42,7 +42,8 @@
 // Max packet size for reception in game setup
 #define MAX_PACKET_SIZE 4096
 
-#define NET_PROTOCOL_VERSION 20
+#define NET_PROTOCOL_VERSION 21
+// version 21 changed OrderModifyWarFlag to more generic OrderModifyMinLevelToFlag
 
 enum OrderTypes
 {
@@ -73,7 +74,7 @@ enum OrderTypes
 	ORDER_MODIFY_SWARM=24,
 	ORDER_MODIFY_FLAG=30,
 	ORDER_MODIFY_CLEARING_FLAG=31,
-	ORDER_MODIFY_WAR_FLAG=32,
+	ORDER_MODIFY_MIN_LEVEL_TO_FLAG=32,
 	ORDER_MOVE_FLAG=35,
 	ORDER_ALTERATE_FORBIDDEN=37,
 	ORDER_ALTERATE_GUARD_AREA=38,
