@@ -19,6 +19,10 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
+/*!	\file SGSL.cpp
+	\brief SGSL: Simple Globulation Scripting Language: implementation of classes for map scripting
+*/
+
 #include <iostream>
 #include <string>
 #include <deque>
@@ -203,26 +207,29 @@ bool Story::conditionTester(const Game *game, int pc, bool l)
 	{
 		case (Token::S_HIGHER):
 		{
+			if (verbose)
 			std::cout << "Story::conditionTester : SGSL thread " << this << " testing "
-				<< Token::getNameByType(type) << " ("
-				<< teamNumber << ", " << level << ") : "
-				<< val << " >? " << amount << std::endl;
+				  << Token::getNameByType(type) << " ("
+				  << teamNumber << ", " << level << ") : "
+				  << val << " >? " << amount << std::endl;
 			return (val > amount);
 		}
 		case (Token::S_LOWER):
 		{
-			std::cout << "Story::conditionTester : SGSL thread " << this << " testing "
-				<< Token::getNameByType(type) << " ("
-				<< teamNumber << ", " << level << ") : "
-				<< val << " <? " << amount << std::endl;
+			if (verbose)
+				std::cout << "Story::conditionTester : SGSL thread " << this << " testing "
+				  << Token::getNameByType(type) << " ("
+					  << teamNumber << ", " << level << ") : "
+					  << val << " <? " << amount << std::endl;
 			return (val < amount);
 		}
 		case (Token::S_EQUAL):
 		{
-			std::cout << "Story::conditionTester : SGSL thread " << this << " testing "
-				<< Token::getNameByType(type) << " ("
-				<< teamNumber << ", " << level << ") : "
-				<< val << " =? " << amount << std::endl;
+			if (verbose)
+				std::cout << "Story::conditionTester : SGSL thread " << this << " testing "
+					  << Token::getNameByType(type) << " ("
+					  << teamNumber << ", " << level << ") : "
+					  << val << " =? " << amount << std::endl;
 			return (val == amount);
 		}
 		default:
@@ -619,13 +626,14 @@ void Story::syncStep(GameGUI *gui)
 {
 	int cycleLeft = 256;
 
-	std::cout << "Story::syncStep : SGSL thread " << this << " PC : " << lineSelector << " (" << Token::getNameByType(line[lineSelector].type) << ")" << std::endl;
+	if (verbose)
+		std::cout << "Story::syncStep : SGSL thread " << this << " PC : " << lineSelector << " (" << Token::getNameByType(line[lineSelector].type) << ")" << std::endl;
 	while (testCondition(gui) && cycleLeft)
 	{
 		lineSelector++;
 		cycleLeft--;
-		
-		std::cout << "Story::syncStep : SGSL thread " << this << " PC : " << lineSelector << " (" << Token::getNameByType(line[lineSelector].type) << ")" << std::endl;
+		if (verbose)
+			std::cout << "Story::syncStep : SGSL thread " << this << " PC : " << lineSelector << " (" << Token::getNameByType(line[lineSelector].type) << ")" << std::endl;
 	}
 
 	if (!cycleLeft)
@@ -680,7 +688,7 @@ Aquisition::Aquisition(void)
 #define HANDLE_ERROR_POS(c) { actPos++; if (c=='\n') { actLine++; actCol=0; } else { actCol++; } }
 #undef getc
 
-#ifdef _MSC_VER
+#ifdef WIN32 
 const char *index(const char *str, char f)
 {
 	for(const char *a=str;*a;a++)
